"""
Type definitions for the contrast-vulnerability-metrics tool.
"""

from typing import TypedDict, Optional, List, Any
from enum import Enum
from datetime import datetime


class Severity(str, Enum):
    """Enumeration of vulnerability severity levels"""
    CRITICAL = "CRITICAL"
    HIGH = "HIGH"
    MEDIUM = "MEDIUM"
    LOW = "LOW"
    NOTE = "NOTE"


class VulnerabilityListItem(TypedDict):
    """Type definition for vulnerability list item from the Contrast API"""
    uuid: str
    title: str
    ruleName: str
    visible: bool
    severity: Severity
    defaultSeverity: Severity
    lastDetected: int  # Unix timestamp in milliseconds
    firstDetected: int  # Unix timestamp in milliseconds
    status: str
    subStatus: str


class VulnerabilityListResponse(TypedDict):
    """Type definition for vulnerability list API response"""
    success: bool
    messages: List[str]
    items: List[dict[str, Any]]  # Each item contains a 'vulnerability' key with VulnerabilityListItem
    count: int
    licensedVulnerabilityCount: int


class VulnerabilityDetail(TypedDict):
    """Type definition for detailed vulnerability data from the Contrast API"""
    uuid: str
    title: str
    severity: str
    severity_label: str
    first_time_seen: int  # Unix timestamp in milliseconds
    last_time_seen: int  # Unix timestamp in milliseconds
    closed_time: Optional[int]  # Unix timestamp in milliseconds
    status: str
    sub_status: str


class VulnerabilityDetailResponse(TypedDict):
    """Type definition for vulnerability detail API response"""
    success: bool
    messages: List[str]
    trace: VulnerabilityDetail


class VulnerabilityMetrics(TypedDict):
    """Type definition for calculated vulnerability metrics"""
    uuid: str
    severity: str
    first_time_seen: datetime
    last_time_seen: datetime
    closed_time: Optional[datetime]
    time_to_last_seen: int  # Duration in days
    time_to_remediation: Optional[int]  # Duration in days

class EnvConfig(TypedDict, total=True):
    """Type definition for environment configuration"""

    CONTRAST_BASE_URL: str
    CONTRAST_ORG_UUID: str
    CONTRAST_API_KEY: str
    CONTRAST_AUTH: str
